@@ -3,11 +3,12 @@ Simply exports the aikido background process
 """
 
 import multiprocessing.connection as con
+import signal
 import time
-import os
 import sched
 import traceback
 import sys
+import platform
 from threading import Thread
 from queue import Queue
 from aikido_zen.helpers.logging import logger
@@ -19,6 +20,7 @@ from aikido_zen.helpers.token import get_token_from_env
 from aikido_zen.background_process.api.http_api_ratelimited import (
     ReportingApiHTTPRatelimited,
 )
+from aikido_zen.helpers.urls.get_api_url import get_api_url
 from .commands import process_incoming_command
 
 EMPTY_QUEUE_INTERVAL = 5  # 5 seconds
@@ -32,22 +34,24 @@ class AikidoBackgroundProcess:
     """
 
     def __init__(self, address, key):
-        logger.debug("Background process started")
         try:
-            listener = con.Listener(address, authkey=key)
+            listener = con.Listener(address, authkey=None)
         except OSError:
-            logger.warning(
-                "Aikido listener may already be running on port %s, exiting", address[1]
-            )
+            logger.debug("not listening, another thread is already listening.")
             sys.exit(0)
         self.queue = Queue()
         self.connection_manager = None
         # Start reporting thread :
-        Thread(target=self.reporting_thread).start()
+        Thread(target=self.reporting_thread, daemon=True).start()
+
+        logger.debug(
+            "Background process started successfully, with UDS File : %s", address
+        )
+
+        add_exit_handlers()
 
         while True:
             conn = listener.accept()
-            logger.debug("connection accepted from %s", listener.last_accepted)
             while True:
                 try:
                     data = conn.recv()  #  because of this no sleep needed in thread
@@ -61,7 +65,7 @@ class AikidoBackgroundProcess:
                     conn.close()  # Sort of EOL for Python IPC
                     break
                 except Exception as e:
-                    logger.error("Exception occured in server thread : %s", e)
+                    logger.error("Exception occurred in server thread : %s", e)
                     logger.debug("Trace \n %s", traceback.format_exc())
                     break  # Return back to listening for new connections
 
@@ -74,7 +78,7 @@ class AikidoBackgroundProcess:
         self.send_to_connection_manager(event_scheduler)
 
         api = ReportingApiHTTPRatelimited(
-            "https://guard.aikido.dev/",
+            reporting_url=get_api_url(),
             max_events_per_interval=100,
             interval_in_ms=60 * 60 * 1000,
         )
@@ -98,10 +102,22 @@ class AikidoBackgroundProcess:
             EMPTY_QUEUE_INTERVAL, 1, self.send_to_connection_manager, (event_scheduler,)
         )
         while not self.queue.empty():
-            queue_attack_item = self.queue.get()
-            self.connection_manager.on_detected_attack(
-                attack=queue_attack_item[0],
-                context=queue_attack_item[1],
-                blocked=queue_attack_item[2],
-                stack=queue_attack_item[3],
-            )
+            self.connection_manager.report_api_event(self.queue.get())
+
+
+def add_exit_handlers():
+    """
+    We add graceful exit handlers here since the process keeps hanging otherwise.
+    """
+
+    def exit_gracefully(sig, frame):
+        sys.exit(0)
+
+    current_platform = platform.system()
+
+    signal.signal(signal.SIGINT, exit_gracefully)
+    signal.signal(signal.SIGTERM, exit_gracefully)
+
+    if current_platform in ("Linux", "Darwin"):
+        signal.signal(signal.SIGQUIT, exit_gracefully)
+        signal.signal(signal.SIGHUP, exit_gracefully)
