@@ -1,10 +1,10 @@
 """Exports process_renew_config"""
 
 from aikido_zen.api_discovery.update_route_info import update_route_info
-from aikido_zen.helpers.logging import logger
+from aikido_zen.background_process.packages import PackagesStore
 
 
-def process_sync_data(connection_manager, data, conn, queue=None):
+def process_sync_data(connection_manager, data):
     """
     Synchronizes data between the thread-local cache (with a TTL of usually 1 minute) and the
     background thread. Which data gets synced?
@@ -32,7 +32,7 @@ def process_sync_data(connection_manager, data, conn, queue=None):
         connection_manager.middleware_installed = True
 
     # Sync hostnames
-    for hostnames_entry in data.get("hostnames", list()):
+    for hostnames_entry in data.get("hostnames", []):
         connection_manager.hostnames.add(
             hostnames_entry["hostname"],
             hostnames_entry["port"],
@@ -40,7 +40,7 @@ def process_sync_data(connection_manager, data, conn, queue=None):
         )
 
     # Sync users
-    for user_entry in data.get("users", list()):
+    for user_entry in data.get("users", []):
         connection_manager.users.add_user_from_entry(user_entry)
 
     # Sync stats
@@ -49,6 +49,9 @@ def process_sync_data(connection_manager, data, conn, queue=None):
     # Sync ai stats
     connection_manager.ai_stats.import_list(data.get("ai_stats", []))
 
+    # Sync packages
+    PackagesStore.import_list(data.get("packages", []))
+
     if connection_manager.conf.last_updated_at > 0:
         # Only report data if the config has been fetched.
         return {
