@@ -2,8 +2,6 @@
 Exports ServiceConfig class
 """
 
-from typing import Pattern
-
 from aikido_zen.helpers.ip_matcher import IPMatcher
 from aikido_zen.helpers.match_endpoints import match_endpoints
 
@@ -24,6 +22,8 @@ class ServiceConfig:
         self.update(
             endpoints, last_updated_at, blocked_uids, bypassed_ips, received_any_stats
         )
+        self.block_new_outgoing_requests = False
+        self.outbound_domains = {}
 
     def update(
         self,
@@ -76,3 +76,23 @@ class ServiceConfig:
     def is_bypassed_ip(self, ip):
         """Checks if the IP is on the bypass list"""
         return self.bypassed_ips.has(ip)
+
+    def update_outbound_domains(self, domains):
+        self.outbound_domains = {
+            domain["hostname"]: domain["mode"] for domain in domains
+        }
+
+    def set_block_new_outgoing_requests(self, value: bool):
+        """Set whether to block new outgoing requests"""
+        self.block_new_outgoing_requests = bool(value)
+
+    def should_block_outgoing_request(self, hostname: str) -> bool:
+        mode = self.outbound_domains.get(hostname)
+
+        if self.block_new_outgoing_requests:
+            # Only allow outgoing requests if the mode is "allow"
+            # mode is None for unknown hostnames, so they get blocked
+            return mode != "allow"
+
+        # Only block outgoing requests if the mode is "block"
+        return mode == "block"
