@@ -6,6 +6,7 @@ import contextvars
 import json
 from json import JSONDecodeError
 from time import sleep
+from typing import Dict
 from urllib.parse import parse_qs
 
 from aikido_zen.helpers.build_route_from_url import build_route_from_url
@@ -45,13 +46,15 @@ class Context:
         # Define emtpy variables/Properties :
         self.source = source
         self.user = None
+        self.rate_limit_group = None
         self.parsed_userinput = {}
         self.xml = {}
         self.outgoing_req_redirects = []
         self.set_body(body)
         self.headers: Headers = Headers()
-        self.cookies = dict()
-        self.query = dict()
+        self.cookies = {}
+        self.query = {}
+        self.protection_forced_off = None
 
         # Parse WSGI/ASGI/... request :
         self.method = self.remote_address = self.url = None
@@ -83,6 +86,7 @@ class Context:
                     "route": self.route,
                     "subdomains": self.subdomains,
                     "user": self.user,
+                    "rate_limit_group": self.rate_limit_group,
                     "xml": self.xml,
                     "outgoing_req_redirects": self.outgoing_req_redirects,
                     "executed_middleware": self.executed_middleware,
@@ -99,6 +103,9 @@ class Context:
         """
         current_context.set(self)
 
+    def set_cookies(self, cookies):
+        self.cookies = cookies
+
     def set_body(self, body):
         try:
             self.set_body_internal(body)
@@ -131,3 +138,6 @@ class Context:
 
     def get_user_agent(self):
         return self.headers.get_header("USER_AGENT")
+
+    def set_force_protection_off(self, value: bool):
+        self.protection_forced_off = value
