@@ -5,10 +5,6 @@ Includes all the wrappers for gunicorn config file
 import aikido_zen
 
 
-# Run our background process as a child of gunicorn (exits safely)
-aikido_zen.protect("daemon_only")
-
-
 def post_fork(prev_func):
     """
     Aikido decorator for gunicorn config
@@ -16,7 +12,7 @@ def post_fork(prev_func):
     """
 
     def aik_post_fork(server, worker):
-        aikido_zen.protect("daemon_disabled")
+        aikido_zen.protect()
         prev_func(server, worker)
 
     return aik_post_fork
